@@ -66,6 +66,10 @@ pub fn main() -> ::std::io::Result<()> {
         // macOS static libraries need the Security.framework for the ring crate
         println!("cargo:rustc-link-lib=framework=Security");
     }
+    if target.contains("windows") {
+        println!("cargo:rustc-link-lib=ntdll");
+        println!("cargo:rustc-link-lib=iphlpapi");
+    }
     Ok(())
 }
 
