@@ -88,6 +88,13 @@ pub enum WebSocketMode {
     Disabled,
 }
 
+#[repr(C)]
+#[derive(Debug, Clone, Copy, PartialEq, Eq)]
+pub enum HistoryTracking {
+    Enabled,
+    Disabled,
+}
+
 #[repr(C)]
 #[derive(Copy, Clone, Debug, PartialEq)]
 #[allow(dead_code)]
@@ -184,6 +191,12 @@ pub enum StringPrimitiveFormat {
     WithoutQuotes,
 }
 
+#[repr(C)]
+pub struct AuthenticationResult {
+    pub return_code: c_int,
+    pub client_info: Option<safer_ffi::String>,
+}
+
 #[apply(extern_type_polyfill!)]
 extern "C" {
     // we need to let the build.rs script control the dylib vs. static choice
@@ -201,6 +214,7 @@ extern "C" {
     pub fn ditto_make(
         uninit_ditto: c::Box<UninitializedDitto>,
         auth_client: &'_ AuthClient,
+        history_tracking: HistoryTracking,
     ) -> c::Box<Ditto>;
 
     pub fn ditto_logger_init();
@@ -350,18 +364,7 @@ extern "C" {
         transaction: c::Box<CWriteTransaction>,
     ) -> c_int;
 
-    pub fn ditto_write_transaction_rollback(transaction: c::Box<CWriteTransaction>);
-
-    pub fn ditto_document_new_cbor(
-        cbor: c_slice::Ref<'_, u8>,
-        id: Option<c_slice::Ref<'_, u8>>,
-        _site_id: c_ulonglong,
-    ) -> c::Result_Box<Document>;
-
-    pub fn ditto_document_new_cbor_default_data(
-        cbor: c_slice::Ref<'_, u8>,
-        id: Option<c_slice::Ref<'_, u8>>,
-    ) -> c::Result_Box<Document>;
+    pub fn ditto_write_transaction_rollback(ditto: &Ditto, transaction: c::Box<CWriteTransaction>);
 
     pub fn ditto_document_id(document: &'_ Document) -> c_slice::Box<u8>;
 
@@ -586,6 +589,13 @@ extern "C" {
         site_id: c_ulonglong,
     ) -> c::Result_Box<AuthClient>;
 
+    pub fn ditto_auth_client_make_anonymous_client(
+        working_dir: char_p::Ref<'_>,
+        app_id: char_p::Ref<'_>,
+        shared_token: char_p::Ref<'_>,
+        base_url: char_p::Ref<'_>,
+    ) -> c::Result_Box<AuthClient>;
+
     pub fn ditto_auth_client_make_with_shared_key(
         working_dir: Option<char_p::Ref<'_>>,
         app_id: char_p::Ref<'_>,
@@ -598,6 +608,7 @@ extern "C" {
     ) -> c::Result_Box<AuthClient>;
 
     pub type AuthClient: Send + Sync;
+
     #[drop]
     pub fn ditto_auth_client_free(auth_client: c::Box<AuthClient>);
 
@@ -631,6 +642,12 @@ extern "C" {
         provider: char_p::Ref<'_>,
     ) -> c_int;
 
+    pub fn ditto_auth_client_login_with_token_and_feedback(
+        auth_client: &'_ AuthClient,
+        token: char_p::Ref<'_>,
+        provider: char_p::Ref<'_>,
+    ) -> AuthenticationResult;
+
     pub fn ditto_auth_client_login_with_token(
         auth_client: &'_ AuthClient,
         token: char_p::Ref<'_>,
@@ -644,25 +661,19 @@ extern "C" {
     #[drop]
     pub fn ditto_auth_login_provider_free(login_provider: c::Box<LoginProvider>);
 
-    pub fn ditto_timeseries_event_from_cbor(
-        timestamp: [u8; 8], // a u64 ... but arm32 friendly
+    pub fn ditto_insert_timeseries_event(
+        ditto: &'_ Ditto,
+        timestamp: [u8; 8], // a u64 ... but arm32
         nanos: u32,
         ts_name: char_p::Ref<'_>,
         cbor: c_slice::Ref<'_, u8>,
-    ) -> c::Result_Box<TimeseriesEvent>;
-
-    pub fn ditto_insert_timeseries_event(
-        ditto: &'_ Ditto,
-        transaction: &'_ mut CWriteTransaction,
-        ts_event: c::Box<TimeseriesEvent>,
+        txn: Option<&'_ mut CWriteTransaction>,
     ) -> c_int;
 
-    pub type TimeseriesEvent;
-    #[drop]
-    pub fn ditto_timeseries_event_free(document: c::Box<TimeseriesEvent>);
-
     pub fn ditto_set_sync_group(ditto: &'_ Ditto, sync_group: c_uint);
 
+    pub fn ditto_set_device_name(ditto: &'_ Ditto, device_name: char_p::Ref<'_>);
+
     pub fn ditto_register_presence_v2_callback(
         ditto: &'_ Ditto,
         ctx: *mut c_void,
